/********************************** intmap.c **********************************
 *
 *  $Id: namelist.c,v 1.1 2002/04/16 20:24:03 irby Exp $
 *
 *  Programmer(s) and Completion Date:
 *     Albert Etienne - Hughes-STX - 02/08/93
 *
 *  Function: This file contains the main routines to handle the intmap XView 
 * 	      interface. The routines prompt the user, get all the required
 *	      inputs, write the namelist and execute the Fortran program. 
 *	      Included in this file is the main program and all the routines
 *	      to handle the widgets in the windows and the 'Run' button
 *	      routine which makes the namelist and runs the program.
 *
 *	      This file was originally obtained from the DevGuide tool and
 *	      corresponds to file mapgen_stubs.c generated by DevGuide. It
 *	      was then extensively manually edited but the basic DevGuide
 *	      structure was kept.
 *
 *  Software System and Spacecraft:  EGRET project
 *
 *  Computer and Language:  Sun 4/280 - C
 *
 *  Calling Sequence:  intmap
 *
 *  Called by:  User
 *
 *  $Log: namelist.c,v $
 *  Revision 1.1  2002/04/16 20:24:03  irby
 *  New GRO tool intmap.
 *
 * Revision 1.10  1999/03/08  21:20:06  lmm
 * changed date upper limit of ACS namelist values from 12/31/99 to 12/31/10
 *
 * Revision 1.9  1995/11/07  22:36:18  programs
 * The new panel lists the 10 standard energy intervals and gives
 * the normalization factor for each even when the input map has
 * fewer and/or non-standard energy intervals.  The normalization
 * for non-standard intervals is construncted from the 10 standard
 * ones, and hence they need to be listed and the user has to have the
 * option to change them.
 * Dave Bertsch
 *
 * Revision 1.8  1994/03/28  18:49:27  albert
 * Modified to use the rsh command instead of on to remotely execute the
 * program. Added all other EGRET hosts in the list of remote hosts.
 *
 * Revision 1.7  1994/03/16  20:06:53  albert
 * Used environment variable to find name of intmap Fortran executable for pi0
 *
 * Revision 1.6  1994/03/11  21:32:11  albert
 * Changed to allow the user to choose the host during input instead of
 * reading it from an environment variable
 *
 * Revision 1.5  1993/06/24  19:02:18  albert
 * Made reading FITS file independent of the energy levels sequence.
 *
 * Revision 1.4  1993/05/05  12:44:22  albert
 * Added -s command line option which allows the user to skip the input phase
 * and run from the namelist. That option also determines whether the regular
 * or the moving target program is to be run.
 *
 * Revision 1.3  1993/02/22  17:14:13  albert
 * Increased precision of scale factors displayed in the window from 1 digit
 * to 3 digits after the decimal point.
 *
 * Revision 1.2  1993/02/10  19:09:48  albert
 * Modified to show the correct FITS directory name in the window
 *
 * Revision 1.1  1993/02/08  14:17:29  albert
 * Initial revision
 *
 *****************************************************************************/

#include "intmap.h"


/* Global object definitions.	*/

static char	*id = "$Id: namelist.c,v 1.1 2002/04/16 20:24:03 irby Exp $";

/******************************************************************************
 * Main routine
 * Verify that the needed environment variables are properly set, initialize
 * XView, initialize the windows, generate the list of FITS files and store
 * it in the scrollable list. Then turn control over to XView.
 *****************************************************************************/
int namelist(char *pFits, char *countFileName, char *exphst, float *specin, 
	     float *fact)
{
   int	skip, i, LEVELS;
   int   status=0;

   char	*machine;
   char  **energy=NULL;
   char  *pEgret =  (char *) malloc(80*sizeof(char));
   char  *pExposr = (char *) malloc(80*sizeof(char));


   /* for (i=0; i<10; ++i) */
	
   /* First get the name of the main EGRET Directory */
   pEgret = pFits;


   /* Make sure that we have write permission on the FITS directory */
   if (access(pFits, W_OK | X_OK) != 0) 
   {
      fprintf(stderr, "FITS directory %s is not writable.\n", pFits);
      fprintf(stderr, "Cannot create an intensity/exposure map ");
      fprintf(stderr, "in that directory.\n");
      status = 1;
   }

   else
   {	 
      /* List the information for the energy levels of the count file */

      energy = (char **) malloc (10*sizeof(char *));
      for (i=0; i<10; ++i)
         energy[i] = (char *) malloc (80*sizeof(char));

      status = listlevel(pFits, countFileName, &LEVELS, fact, specin, energy);
      if (status == 0)
      {
         fflush(NULL);
         pExposr = pFits;

         sprintf(exphst, "%sexphst_v01p.0040", pExposr);
  
         fflush(NULL);
      }
   }

   return status;
}

